/*
 * Created on 04.01.2005
 *
 * $Id$
 */
package casino.player;

import casino.*;

/**
 * Ein einfacher Spieler.
 * 
 * @author <a href="mailto:boehm@javatux.de">oliver</a>
 * @since 04.01.2005
 * @version $revision$
 */
public class Player implements RoulettePlayer {

    private String name = null;
    private Konto konto = null;

    /**
     * Der Konstruktor kann leider nicht ueber die Default-Implementierung
     * bereitgestellt werden.
     * 
     * @param name  Spielername
     */
    public Player(String name) {
        this(name, new Konto(name, 5000));        
    }
    
    /**
     * @param name  Spielername
     * @param konto Startkapital
     */
    public Player(String name, Konto konto) {
        this.setName(name);
        this.setKonto(konto);        
    }
    
    /**
     * Lassen wir den Computer automatisch den Wett-Einsatz taetigen -
     * 50 Chips auf "Pair" - die Chips dafür werden gleich vom Konto 
     * abgehoben.
     * 
     * @return den Wett-Einsatz
     */
    public Einsatz getEinsatz() {
        Einsatz einsatz = new Einsatz();
        einsatz.setPair(50);
        this.setEinsatz(einsatz);
        return einsatz;
    }
    
    /**
     * Der Einsatz geht vom Konto ab.
     */
    public void setEinsatz(Einsatz einsatz) {
        konto.abheben(einsatz.getBetrag());
    }
    
    /**
     * Der Gweinn wird auf dem Konto verbucht.
     */
    public void setGewinn(Einsatz gewinn) {
        konto.einzahlen(gewinn.getBetrag());
    }
    
    /**
     * Wieviel ist denn noch auf dem Konto?
     */
    public int getKontostand() {
        return this.konto.abfragen();
    }
    
    /**
     * Spielername zurueckgeben.
     */
    public String toString() {
        return this.name;
    }
    
    /**
     * Fuer den Zugriff auf "name" stellen wir noch diese Methode bereit
     */
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * Um das Konto setzen zu koennen, stellen wir ebenfalls noch eine Methode
     * bereit.
     */
    public void setKonto(Konto konto) {
        this.konto = konto;
    }

}
