/*
 * Created on 23.09.2004
 */
package casino.log;

//import org.apache.log4j.*;
import org.apache.commons.logging.*;
import org.aspectj.lang.*;

import casino.*;

/**
 * Ein allgemeiner LogAspect fuer die aufgetreteen Exceptions und
 * anderen wichtigen Ereignisse.
 * 
 * @author oliver
 * @since 23.09.2004
 */
public aspect LogAspect {
    
    //private static Logger log = Logger.getLogger(LogAspect.class); 
    private static Log log = LogFactory.getLog(LogAspect.class);


    
    /*
     * Automatische Protokollierung aller abgefangenen Exceptions
     */
    
    /** alle Excption-Handler */
    pointcut handleExceptions() :
        handler(Exception+);
    
    /**
     * Protokolliert alle abgefangenen Exceptions.
     */
    before() : handleExceptions() {
        Signature sig = thisJoinPoint.getSignature();
        log.warn(sig + " in " + thisJoinPoint.getThis());
    }
    
    /**
     * RuntimeExcptions, die nicht unbedingt abgefangen werden muessen,
     * werden zur Sicherheit ebenfalls protokolliert.
     */
    after() : call(public RuntimeException+.new(..)) {
        Signature sig = thisJoinPoint.getSignature();
        log.error(sig.getDeclaringTypeName() + " aufgetreten in "
                + thisJoinPoint.getSourceLocation());
    }
    
    
    
    /**
     * Buchfuehrung ueber saemtliche Methodenaufrufe von store() und load()
     */
    before() : call(public * *..*(..)) &&
            (withincode(public void Konto.store())
            || withincode(public void Konto.load())) {
        log.debug("store/load: " + thisJoinPoint.toShortString());
    }
    
    
    
    /**
     * Kontostand-Ueberwachung
     */
    after(int x) : set(private int Konto.kontostand) && args(x) {
        log.info("Kontostand aendert sich zu " + x);
    }

}
