/*
 * Created on 06.01.2005
 *
 * $Id$
 */
package casino.log;

import casino.*;
import casino.player.*;


/**
 * Gewinn/Verlust-Rechnung und Statistik
 * 
 * @author <a href="mailto:boehm@javatux.de">oliver</a>
 * @since 06.01.2005
 * @version $revision$
 */
public aspect StatisticAspect 
        percflow(execution(public void Croupier.run())) {
    
    private String spieler = null;
    private int eingesetzt = 0;
    private int gesamtEinsatz = 0;
    private int gewonnen = 0;
    private int gesamtGewinn = 0;
    private int anzahlSpiele = 0;
    private int gewonneneSpiele = 0;
    
    /**
     * Name des Spielers merken
     */
    before(Croupier c) : execution(public void Croupier.run()) && this(c) {
        spieler = c.getPlayer().toString();
    }
    
    /**
     * Nach jedem Einsatz wird dieser zwischengespeichert fuer die
     * Auswertung nach der Ziehung.
     */
    after() returning(Einsatz einsatz) :
            execution(public Einsatz RoulettePlayer+.getEinsatz()) {
        eingesetzt = einsatz.getBetrag();
        gesamtEinsatz += eingesetzt;
        anzahlSpiele++;
        //System.err.println("Spiel " + anzahlSpiele + ", Einsatz: " + eingesetzt);
    }
    
    /**
     * War der Gewinn groesser als der Einsatz?
     */
    after(Einsatz gewinn) : 
            execution(public void RoulettePlayer+.setGewinn(Einsatz))
            && args(gewinn) {
        gewonnen = gewinn.getBetrag();
        gesamtGewinn += gewonnen;
        if (gewonnen > eingesetzt) {
            gewonneneSpiele++;
        }
    }
    
    /**
     * Ok, am Ende der Croupier.run()-Methode werden die statischen Daten
     * ausgewertet und auf der Console ausgegeben.
     */
    after() : execution(public void Croupier.run()) {
        System.err.println("===== STATISTIK FUER " + spieler + " =====");
        System.err.println("Anzahl Spiele: " + anzahlSpiele
                + ", davon gewonnen: " + gewonneneSpiele);
        System.err.print("Gesamteinsatz: " + gesamtEinsatz
                + ", Gewinn: " + gesamtGewinn + " ==> ");
        int gewinn = gesamtGewinn - gesamtEinsatz;
        if (gewinn >= 0) {
            System.err.println("GEWINN:  " + gewinn);
        } else {
            System.err.println("VERLUST: " + gewinn);
        }
    }

}
