/*
 * Created on 06.01.2005
 *
 * $Id$
 */
package casino.log;

//import org.apache.log4j.*;
import org.apache.commons.logging.*;
import org.aspectj.lang.*;


/**
 * Dieser Aspekt uebernimmt das Logging.
 * 
 * @author <a href="mailto:boehm@javatux.de">oliver</a>
 * @since 06.01.2005
 * @version $revision$
 */
public abstract aspect AbstractLoggingAspect {

    /** welcher Logger soll verwendet werden? */
    //public abstract Logger getLogger();
    public abstract Log getLogger();
   
    /** die abgeleiteten Aspekte definieren, was geloggt werden soll. */
    abstract pointcut logPoints(Object x);
    
    /**
     * Gibt den Joinpoint inkl. Argumente aus. Zusaetzlich wird das Ergebnis der
     * Methode, der Rueckgabewert, ausgegeben.
     */
    after(Object x) returning(Object r): logPoints(x) {
        String returned = "";
        if (r != null) {
            returned = " = " + r;
        }
        Signature sig = thisJoinPoint.getSignature();
        //getLogger().info(x + ": " 
        getLogger().info("<-- "
                + thisJoinPoint.getKind() + " "
                + sig.getDeclaringType().getName() + "."
                + sig.getName() + "("
                + getArgsAsString(thisJoinPoint.getArgs()) + ")" + returned);
    }
    
    /**
     * Der before()-Joinpoint hilft, Rekursionen besser zu entdecken!
     */
    before(Object x) : logPoints(x) {
        Signature sig = thisJoinPoint.getSignature();
        getLogger().info("--> " 
                + thisJoinPoint.getKind() + " "
                + sig.getDeclaringType().getName() + "."
                + sig.getName() + "("
                + getArgsAsString(thisJoinPoint.getArgs()) + ")");
//        getLogger().info("--> " + thisJoinPoint.toShortString());
    }
    
    private String getArgsAsString(Object[] args) {
        if (args.length == 0) {
            return "";
        }
        String s = "'" + args[0] + "'";
        for (int i = 1; i < args.length; i++) {
            s += ", '" + args[i] + "'";
        }
        return s;
    }

}
